==> qtjambi-xml-5.15.4-sources.jar: io/qt/xml/QXmlLocator.java <==
package io.qt.xml;


/**
 * <p>The XML handler classes with information about the parsing position within a file</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmllocator.html">QXmlLocator</a></p>
 */
@Deprecated
public abstract class QXmlLocator extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QXmlLocator {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public int columnNumber(){
            return columnNumber_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native int columnNumber_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public int lineNumber(){
            return lineNumber_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native int lineNumber_native_constfct(long __this__nativeId);
        
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllocator.html#QXmlLocator">QXmlLocator::QXmlLocator()</a></p>
     */
    public QXmlLocator(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlLocator instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllocator.html#columnNumber">QXmlLocator::columnNumber()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract int columnNumber();
    
    @io.qt.QtUninvokable
    private native int columnNumber_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllocator.html#lineNumber">QXmlLocator::lineNumber()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract int lineNumber();
    
    @io.qt.QtUninvokable
    private native int lineNumber_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlLocator(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-xml-5.15.13-sources.jar: io/qt/xml/QXmlLocator.java <==
package io.qt.xml;


/**
 * <p>The XML handler classes with information about the parsing position within a file</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmllocator.html">QXmlLocator</a></p>
 */
@Deprecated
public abstract class QXmlLocator extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QXmlLocator {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public int columnNumber(){
            return columnNumber_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native int columnNumber_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public int lineNumber(){
            return lineNumber_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native int lineNumber_native_constfct(long __this__nativeId);
        
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllocator.html#QXmlLocator">QXmlLocator::QXmlLocator()</a></p>
     */
    public QXmlLocator(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlLocator instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllocator.html#columnNumber">QXmlLocator::columnNumber()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract int columnNumber();
    
    @io.qt.QtUninvokable
    private native int columnNumber_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmllocator.html#lineNumber">QXmlLocator::lineNumber()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract int lineNumber();
    
    @io.qt.QtUninvokable
    private native int lineNumber_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlLocator(QPrivateConstructor p) { super(p); } 
    
}
